pub fn ingest_auto(
input: &Path,
output: &Path,
) -> Result<(IngestStats, SemanticFormat), Box<dyn Error>>Expand description
Dispatch to the correct ingest function based on auto-detected format.
pub fn ingest_auto(
input: &Path,
output: &Path,
) -> Result<(IngestStats, SemanticFormat), Box<dyn Error>>Dispatch to the correct ingest function based on auto-detected format.